@@ -3,16 +3,16 @@
  * Copyright (C) 2008-2010, Nokia
  *
  * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
+ * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
+ * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the
  * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
  * Boston, MA  02110-1301, USA.
@@ -21,6 +21,10 @@
 #ifndef __TRACKER_CLIENT_H__
 #define __TRACKER_CLIENT_H__
 
+#if !defined (__LIBTRACKER_CLIENT_INSIDE__) && !defined (TRACKER_COMPILATION)
+#error "only <libtracker-client/tracker-client.h> must be included directly."
+#endif
+
 #include <glib-object.h>
 
 G_BEGIN_DECLS
@@ -89,8 +93,13 @@ gboolean       tracker_cancel_call                         (TrackerClient
                                                             guint                   call_id);
 gboolean       tracker_cancel_last_call                    (TrackerClient          *client);
 
+/* Utilities */
 gchar *        tracker_sparql_escape                       (const gchar            *str);
 
+gchar *        tracker_uri_vprintf_escaped                 (const gchar            *format,
+                                                            va_list                 args);
+gchar *        tracker_uri_printf_escaped                  (const gchar            *format, 
+                                                            ...);
 
 /* Synchronous API */
 GPtrArray *    tracker_statistics_get                      (TrackerClient          *client,
