@@ -25,10 +25,6 @@
 
 #include <glib.h>
 
-#include <libtracker-common/tracker-language.h>
-#include <libtracker-common/tracker-ontologies.h>
-#include <libtracker-common/tracker-property.h>
-
 #include <libtracker-db/tracker-db-interface.h>
 
 G_BEGIN_DECLS
