@@ -77,25 +77,23 @@ void     tracker_data_insert_statement_with_string  (const gchar               *
                                                      const gchar               *predicate,
                                                      const gchar               *object,
                                                      GError                   **error);
-void     tracker_data_begin_transaction             (void);
-void     tracker_data_begin_replay_transaction      (time_t                     time);
-void     tracker_data_commit_transaction            (void);
+void     tracker_data_begin_db_transaction          (void);
+void     tracker_data_begin_db_transaction_for_replay (time_t                   time);
+void     tracker_data_commit_db_transaction         (void);
+void     tracker_data_begin_transaction             (GError                   **error);
+void     tracker_data_commit_transaction            (GError                   **error);
+void     tracker_data_rollback_transaction          (void);
 void     tracker_data_update_sparql                 (const gchar               *update,
                                                      GError                   **error);
 GPtrArray *
-tracker_data_update_sparql_blank           (const gchar               *update,
-                                            GError                   **error);
+         tracker_data_update_sparql_blank           (const gchar               *update,
+                                                     GError                   **error);
 void     tracker_data_update_buffer_flush           (GError                   **error);
 void     tracker_data_update_buffer_might_flush     (GError                   **error);
 
 void     tracker_data_sync                          (void);
-
-/* Volume handling */
-void     tracker_data_update_enable_volume          (const gchar               *udi,
-                                                     const gchar               *mount_path);
-void     tracker_data_update_disable_volume         (const gchar               *udi);
-void     tracker_data_update_disable_all_volumes    (void);
-void     tracker_data_update_reset_volume           (const gchar               *uri);
+void     tracker_data_replay_journal                (GHashTable                *classes,
+                                                     GHashTable                *properties);
 
 /* Calling back */
 void     tracker_data_add_insert_statement_callback   (TrackerStatementCallback   callback,
