@@ -54,7 +54,8 @@ typedef struct {
 
 typedef struct {
 	GFile    *file;
-	gboolean  recurse;
+	guint     recurse : 1;
+	guint     ref_count : 7;
 } DirectoryData;
 
 typedef struct {
@@ -193,7 +194,8 @@ static void           miner_ignore_next_update            (TrackerMiner
                                                            const GStrv           subjects);
 static DirectoryData *directory_data_new                  (GFile                *file,
                                                            gboolean              recurse);
-static void           directory_data_free                 (DirectoryData        *dd);
+static DirectoryData *directory_data_ref                  (DirectoryData        *dd);
+static void           directory_data_unref                (DirectoryData        *dd);
 static ItemMovedData *item_moved_data_new                 (GFile                *file,
                                                            GFile                *source_file);
 static void           item_moved_data_free                (ItemMovedData        *data);
@@ -245,6 +247,11 @@ static void           item_update_children_uri            (TrackerMinerFS
                                                            const gchar          *uri);
 static void           crawled_directory_data_free         (CrawledDirectoryData *data);
 
+static gboolean       should_recurse_for_directory            (TrackerMinerFS *fs,
+							       GFile          *file);
+static void           tracker_miner_fs_directory_add_internal (TrackerMinerFS *fs,
+							       GFile          *file);
+
 
 static guint signals[LAST_SIGNAL] = { 0, };
 
@@ -606,14 +613,13 @@ fs_finalize (GObject *object)
 
 	g_free (priv->current_parent_urn);
 
-	/* Not a leak, contents are actually owned
-	 * by priv->config_directories, being freed
-	 * right below.
-	 */
-	g_list_free (priv->directories);
+	if (priv->directories) {
+		g_list_foreach (priv->directories, (GFunc) directory_data_unref, NULL);
+		g_list_free (priv->directories);
+	}
 
 	if (priv->config_directories) {
-		g_list_foreach (priv->config_directories, (GFunc) directory_data_free, NULL);
+		g_list_foreach (priv->config_directories, (GFunc) directory_data_unref, NULL);
 		g_list_free (priv->config_directories);
 	}
 
@@ -795,19 +801,31 @@ directory_data_new (GFile    *file,
 
 	dd->file = g_object_ref (file);
 	dd->recurse = recurse;
+	dd->ref_count = 1;
 
 	return dd;
 }
 
+static DirectoryData *
+directory_data_ref (DirectoryData *dd)
+{
+	dd->ref_count++;
+	return dd;
+}
+
 static void
-directory_data_free (DirectoryData *dd)
+directory_data_unref (DirectoryData *dd)
 {
 	if (!dd) {
 		return;
 	}
 
-	g_object_unref (dd->file);
-	g_slice_free (DirectoryData, dd);
+	dd->ref_count--;
+
+	if (dd->ref_count == 0) {
+		g_object_unref (dd->file);
+		g_slice_free (DirectoryData, dd);
+	}
 }
 
 static void
@@ -1108,11 +1126,7 @@ item_add_or_update_cb (TrackerMinerFS *fs,
 
 			do_process_file (fs, data);
 		} else {
-			if (error->code == G_IO_ERROR_NOT_FOUND) {
-				g_message ("Could not process '%s': %s", uri, error->message);
-			} else {
-				g_critical ("Could not process '%s': %s", uri, error->message);
-			}
+                        g_message ("Could not process '%s': %s", uri, error->message);
 
 			fs->private->total_files_notified_error++;
 			fs->private->processing_pool =
@@ -1252,7 +1266,7 @@ item_remove (TrackerMinerFS *fs,
 	                        "  ?child a rdfs:Resource "
 	                        "} WHERE {"
 	                        "  ?child nie:url ?u . "
-	                        "  FILTER (fn:starts-with (?u, '%s')) "
+	                        "  FILTER (fn:starts-with (?u, \"%s\")) "
 	                        "}",
 	                        slash_uri);
 
@@ -1261,7 +1275,7 @@ item_remove (TrackerMinerFS *fs,
 	                        "DELETE { "
 	                        "  ?u a rdfs:Resource "
 	                        "} WHERE { "
-	                        "  ?u nie:url '%s' "
+	                        "  ?u nie:url \"%s\" "
 	                        "}",
 	                        uri);
 
@@ -1348,7 +1362,7 @@ item_ignore_next_update (TrackerMinerFS *fs,
 		                         "     nfo:fileLastModified ?unknown2 ; "
 		                         "     nfo:fileLastAccessed ?unknown3 ; "
 		                         "     nie:mimeType ?unknown4 ; "
-		                         "     nie:url '%s' "
+		                         "     nie:url \"%s\" "
 		                         "} %s",
 		                         uri, tracker_sparql_builder_get_result (sparql));
 
@@ -1415,7 +1429,7 @@ item_update_children_uri_cb (GObject      *object,
 
 			g_string_append_printf (data->sparql,
 			                        "INSERT INTO <%s> {"
-			                        "  <%s> nie:url '%s' "
+			                        "  <%s> nie:url \"%s\" "
 			                        "} ",
 			                        child_urn, child_urn, child_uri);
 
@@ -1438,11 +1452,8 @@ item_update_children_uri (TrackerMinerFS    *fs,
 
 	slash_uri = g_strconcat (source_uri, "/", NULL);
 
-	sparql = g_strdup_printf ("SELECT ?child ?url ?m WHERE { "
+	sparql = g_strdup_printf ("SELECT ?child ?url nie:mimeType(?child) WHERE { "
 				  "  ?child nie:url ?url . "
-				  "  OPTIONAL { "
-				  "    ?child nie:mimeType ?m "
-				  "  } . "
 				  "  FILTER (fn:starts-with (?url, \"%s\")) "
 				  "}",
 				  slash_uri);
@@ -1507,9 +1518,10 @@ item_move (TrackerMinerFS *fs,
 
 		file_type = g_file_info_get_file_type (file_info);
 
-		if (file_type == G_FILE_TYPE_DIRECTORY) {
-			/* We're dealing with a directory, index recursively */
-			tracker_miner_fs_directory_add (fs, file, TRUE);
+		if (file_type == G_FILE_TYPE_DIRECTORY &&
+		    should_recurse_for_directory (fs, file)) {
+			/* We're dealing with a recursive directory */
+			tracker_miner_fs_directory_add_internal (fs, file);
 			retval = TRUE;
 		} else {
 			retval = item_add_or_update (fs, file);
@@ -1556,8 +1568,8 @@ item_move (TrackerMinerFS *fs,
 
 	g_string_append_printf (sparql,
 	                        "INSERT INTO <%s> {"
-	                        "  <%s> nfo:fileName '%s' ; "
-	                        "       nie:url '%s' ; "
+	                        "  <%s> nfo:fileName \"%s\" ; "
+	                        "       nie:url \"%s\" ; "
 	                        "       nie:isStoredAs <%s> "
 	                        "} ",
 	                        source_iri, source_iri,
@@ -2123,8 +2135,9 @@ monitor_item_created_cb (TrackerMonitor *monitor,
 	         is_directory ? "DIR" : "FILE");
 
 	if (should_process) {
-		if (is_directory) {
-			tracker_miner_fs_directory_add (fs, file, TRUE);
+		if (is_directory &&
+		    should_recurse_for_directory (fs, file)) {
+			tracker_miner_fs_directory_add_internal (fs, file);
 		} else {
 			g_queue_push_tail (fs->private->items_created,
 			                   g_object_ref (file));
@@ -2207,7 +2220,7 @@ monitor_item_deleted_cb (TrackerMonitor *monitor,
 	 * in process_device_next()
 	 */
 	if (l && l != fs->private->current_directory) {
-		directory_data_free (l->data);
+		directory_data_unref (l->data);
 		fs->private->directories =
 			g_list_delete_link (fs->private->directories, l);
 	}
@@ -2229,7 +2242,8 @@ monitor_item_moved_cb (TrackerMonitor *monitor,
 	fs = user_data;
 
 	if (!is_source_monitored) {
-		if (is_directory) {
+		if (is_directory &&
+		    should_recurse_for_directory (fs, other_file)) {
 			gchar *path;
 
 			path = g_file_get_path (other_file);
@@ -2238,7 +2252,7 @@ monitor_item_moved_cb (TrackerMonitor *monitor,
 			         path);
 
 			/* If the source is not monitored, we need to crawl it. */
-			tracker_miner_fs_directory_add (fs, other_file, TRUE);
+			tracker_miner_fs_directory_add_internal (fs, other_file);
 
 			g_free (path);
 		}
@@ -2270,7 +2284,8 @@ monitor_item_moved_cb (TrackerMonitor *monitor,
 			/* Do nothing */
 		} else if (!source_stored) {
 			/* Source file was not stored, check dest file as new */
-			if (!is_directory) {
+			if (!is_directory ||
+			    !should_recurse_for_directory (fs, other_file)) {
 				g_queue_push_tail (fs->private->items_created,
 				                   g_object_ref (other_file));
 
@@ -2279,7 +2294,7 @@ monitor_item_moved_cb (TrackerMonitor *monitor,
 				g_debug ("Not in store:'?'->'%s' (DIR) (move monitor event, source monitored)",
 				         path);
 
-				tracker_miner_fs_directory_add (fs, other_file, TRUE);
+				tracker_miner_fs_directory_add_internal (fs, other_file);
 			}
 		} else if (!should_process_other) {
 			/* Delete old file */
@@ -2495,6 +2510,7 @@ crawler_finished_cb (TrackerCrawler *crawler,
 	           was_interrupted ? "Stopped" : "Finished",
 	           g_timer_elapsed (fs->private->timer, NULL));
 
+	directory_data_unref (fs->private->current_directory);
 	fs->private->current_directory = NULL;
 
 	/* Proceed to next thing to process */
@@ -2555,6 +2571,7 @@ crawl_directories_cb (gpointer user_data)
 	}
 
 	/* Directory couldn't be processed */
+	directory_data_unref (fs->private->current_directory);
 	fs->private->current_directory = NULL;
 
 	return TRUE;
@@ -2608,6 +2625,50 @@ crawl_directories_stop (TrackerMinerFS *fs)
 	}
 }
 
+static gboolean
+should_recurse_for_directory (TrackerMinerFS *fs,
+			      GFile          *file)
+{
+	gboolean recurse = FALSE;
+	GList *dirs;
+
+	for (dirs = fs->private->config_directories; dirs; dirs = dirs->next) {
+		DirectoryData *data;
+
+		data = dirs->data;
+
+		if (data->recurse &&
+		    (g_file_equal (file, data->file) ||
+		     g_file_has_prefix (file, data->file))) {
+			/* File is inside a recursive dir */
+			recurse = TRUE;
+			break;
+		}
+	}
+
+	return recurse;
+}
+
+/* This function is for internal use, adds the file to the processing
+ * queue with the same directory settings than the corresponding
+ * config directory.
+ */
+static void
+tracker_miner_fs_directory_add_internal (TrackerMinerFS *fs,
+					 GFile          *file)
+{
+	DirectoryData *data;
+	gboolean recurse;
+
+	recurse = should_recurse_for_directory (fs, file);
+	data = directory_data_new (file, recurse);
+
+	fs->private->directories =
+		g_list_append (fs->private->directories, data);
+
+	crawl_directories_start (fs);
+}
+
 /**
  * tracker_miner_fs_directory_add:
  * @fs: a #TrackerMinerFS
@@ -2632,7 +2693,8 @@ tracker_miner_fs_directory_add (TrackerMinerFS *fs,
 		g_list_append (fs->private->config_directories, dir_data);
 
 	fs->private->directories =
-		g_list_append (fs->private->directories, dir_data);
+		g_list_append (fs->private->directories,
+			       directory_data_ref (dir_data));
 
 	crawl_directories_start (fs);
 }
@@ -2704,6 +2766,7 @@ tracker_miner_fs_directory_remove (TrackerMinerFS *fs,
 
 		if (g_file_equal (file, data->file) ||
 		    g_file_has_prefix (file, data->file)) {
+			directory_data_unref (data);
 			fs->private->directories = g_list_delete_link (fs->private->directories, link);
 			return_val = TRUE;
 		}
@@ -2718,8 +2781,8 @@ tracker_miner_fs_directory_remove (TrackerMinerFS *fs,
 		dirs = dirs->next;
 
 		if (g_file_equal (file, data->file)) {
-			directory_data_free (data);
-			fs->private->directories = g_list_delete_link (fs->private->directories, link);
+			directory_data_unref (data);
+			fs->private->config_directories = g_list_delete_link (fs->private->config_directories, link);
 			return_val = TRUE;
 		}
 	}
@@ -2974,6 +3037,8 @@ tracker_miner_fs_force_recheck (TrackerMinerFS *fs)
 	g_message ("Forcing re-check on all index directories");
 
 	directories = g_list_copy (fs->private->config_directories);
+	g_list_foreach (directories, (GFunc) directory_data_ref, NULL);
+
 	fs->private->directories = g_list_concat (fs->private->directories, directories);
 
 	crawl_directories_start (fs);
