@@ -1,4 +1,3 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * Copyright (C) 2008, Nokia
  *
@@ -36,4 +35,4 @@ gboolean tracker_albumart_process  (const unsigned char *buffer,
 
 G_END_DECLS
 
-#endif /* __TRACKER_MINER_EXTRACT_H__ */
+#endif /* __TRACKER_EXTRACT_EXTRACT_H__ */
