@@ -72,6 +72,26 @@ const TestInfo nmo_tests[] = {
 	{ NULL }
 };
 
+static void
+test_ontology_init (void)
+{
+	/* first-time initialization */
+	tracker_data_manager_init (TRACKER_DB_MANAGER_FORCE_REINDEX,
+	                           NULL,
+	                           NULL,
+	                           FALSE);
+
+	tracker_data_manager_shutdown ();
+
+	/* initialization from existing database */
+	tracker_data_manager_init (0,
+	                           NULL,
+	                           NULL,
+	                           FALSE);
+
+	tracker_data_manager_shutdown ();
+}
+
 static void
 test_query (gconstpointer test_data)
 {
@@ -95,13 +115,14 @@ test_query (gconstpointer test_data)
 	/* initialization */
 	tracker_data_manager_init (TRACKER_DB_MANAGER_FORCE_REINDEX,
 	                           NULL,
-	                           NULL);
+	                           NULL, 
+	                           FALSE);
 
 	/* load data set */
 	data_filename = g_strconcat (data_prefix, ".ttl", NULL);
-	tracker_data_begin_transaction ();
+	tracker_data_begin_db_transaction ();
 	tracker_turtle_reader_load (data_filename, &error);
-	tracker_data_commit_transaction ();
+	tracker_data_commit_db_transaction ();
 	g_assert_no_error (error);
 
 	query_filename = g_strconcat (test_prefix, ".rq", NULL);
@@ -225,6 +246,8 @@ main (int argc, char **argv)
 
 	/* add test cases */
 
+	g_test_add_func ("/libtracker-data/ontology-init", test_ontology_init);
+
 	for (i = 0; nie_tests[i].test_name; i++) {
 		gchar *testpath;
 
